variable "customer_name" {
  description = "Account canonical name"
}

variable "environment" {
  description = "Account environment type"
  default     = "ops"
}

variable "child_accounts" {
  description = "List of child AWS account ID's"
  type        = "list"
}

data "aws_iam_policy_document" "main" {
  statement {
    sid       = "AWSCloudTrailAclCheck"
    effect    = "Allow"
    actions   = ["s3:GetBucketAcl"]
    resources = ["arn:aws:s3:::${var.customer_name}-${var.environment}-cloudtrail"]

    principals {
      type        = "Service"
      identifiers = ["cloudtrail.amazonaws.com"]
    }
  }

  statement {
    sid       = "AWSCloudTrailWrite"
    effect    = "Allow"
    actions   = ["s3:PutObject"]
    resources = ["arn:aws:s3:::${var.customer_name}-${var.environment}-cloudtrail/*"]

    principals {
      type        = "Service"
      identifiers = ["cloudtrail.amazonaws.com"]
    }

    condition {
      test     = "StringEquals"
      variable = "s3:x-amz-acl"
      values   = ["bucket-owner-full-control"]
    }
  }

  statement {
    sid       = "AWSCloudTrailWrite"
    effect    = "Allow"
    actions   = ["s3:PutObject"]
    resources = ["${formatlist("arn:aws:s3:::${var.customer_name}-${var.environment}-cloudtrail/AWSLogs/%s/*", var.child_accounts)}"]

    principals {
      type        = "Service"
      identifiers = ["cloudtrail.amazonaws.com"]
    }

    condition {
      test     = "StringEquals"
      variable = "s3:x-amz-acl"
      values   = ["bucket-owner-full-control"]
    }
  }
}

resource "aws_s3_bucket" "main" {
  bucket        = "${var.customer_name}-${var.environment}-cloudtrail"
  force_destroy = true
  policy        = "${data.aws_iam_policy_document.main.json}"
}

resource "aws_cloudtrail" "main" {
  name                          = "${var.customer_name}-${var.environment}-cloudtrail"
  s3_bucket_name                = "${aws_s3_bucket.main.id}"
  include_global_service_events = true
}

output "bucket_name" {
  value = "${aws_s3_bucket.main.id}"
}

output "cloudtrail_name" {
  value = "${aws_cloudtrail.main.id}"
}
